// Copyright (c) Microsoft Corporation.
// Licensed under the MIT license.
/**
 * @internal
 */
export function getHeaderName() {
    return "x-ms-useragent";
}
function getBrandVersionString(brands) {
    // Check for Microsoft Edge
    const edge = brands.find((b) => b.brand === "Microsoft Edge");
    if (edge) {
        return edge;
    }
    // Check for Chrome
    const chrome = brands.find((b) => b.brand === "Google Chrome");
    if (chrome) {
        return chrome;
    }
    // Check for Chromium
    const chromium = brands.find((b) => b.brand === "Chromium");
    if (chromium) {
        return chromium;
    }
    return undefined;
}
/**
 * @internal
 */
export async function setPlatformSpecificData(map) {
    const localNavigator = globalThis.navigator;
    let osPlatform = "unknown";
    if (localNavigator.userAgentData) {
        const entropyValues = await localNavigator.userAgentData.getHighEntropyValues([
            "architecture",
            "platformVersion",
        ]);
        osPlatform = `${entropyValues.architecture}-${entropyValues.platform}-${entropyValues.platformVersion}`;
        // Get the brand and version
        const brand = getBrandVersionString(entropyValues.brands);
        if (brand) {
            map.set(brand.brand, brand.version);
        }
    }
    else if (localNavigator === null || localNavigator === void 0 ? void 0 : localNavigator.platform) {
        osPlatform = localNavigator.platform;
    }
    map.set("OS", osPlatform);
}
//# sourceMappingURL=userAgentPlatform-browser.mjs.map